<?php
namespace EMS\PortalFuncionario\Geral\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use EMS\PortalFuncionario\Geral\Services\EstruturaService;

class EstruturaController {
    /** @var EntityManager */
    protected $entityManager;

    /** @var EstruturaService */
    protected $estruturaService;

    public function __construct(
        EntityManager $entityManager,
        EstruturaService $estruturaService
    ) {
        $this->entityManager            = $entityManager;
        $this->estruturaService         = $estruturaService;
    }

    public function getPontoAcesso(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $pontoAcesso = $this->estruturaService->getPontoAcesso(
                $params['NRORG'],
                $params['NRVINCULOM']
            );
            $response->addDataSet(new DataSet('pontoAcesso', $pontoAcesso));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function getEstrutura(
        DTO\Request\Filter $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];
            $nmTipo = $row['NMTIPOESTRUTURA'];

            $estruturas = $this->estruturaService->getEstrutura(
                $nrOrg, $nmTipo
            );

            $response->addDataSet(new DataSet('getEstrutura', $estruturas));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace(), $e));
        }
    }
}